NetworkException class

Thrown when network operations fail.

Inheritance

Constructors

NetworkException(String message, {int? statusCode, String? code = 'NETWORK_ERROR', dynamic originalError, StackTrace? stackTrace})
const

Properties

code String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
originalError → dynamic
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
finalinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited