EventlyScreenTime class
A completed period during which a screen was visible in the foreground.
- Annotations
Constructors
- EventlyScreenTime({required String screenName, required Duration duration})
-
const
Properties
- duration → Duration
-
Foreground-visible time for this screen visit.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ Map<
String, dynamic> -
Properties suitable for sending with an Evently event.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenName → String
-
The stable analytics name resolved from the route.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited